# Generated by Django 6.0.3 on 2026-03-11 14:37

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sandwitches", "0022_historicalrecipe_instagram_uploaded_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalrecipe",
            name="instagram_likes_count",
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name="historicalrecipe",
            name="instagram_media_id",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name="recipe",
            name="instagram_likes_count",
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name="recipe",
            name="instagram_media_id",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.CreateModel(
            name="InstagramComment",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("instagram_comment_id", models.CharField(max_length=255, unique=True)),
                ("username", models.CharField(max_length=255)),
                ("text", models.TextField()),
                ("created_at", models.DateTimeField()),
                (
                    "recipe",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="instagram_comments",
                        to="sandwitches.recipe",
                    ),
                ),
            ],
            options={
                "ordering": ("-created_at",),
            },
        ),
    ]
